;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "mini-echo" "20251203.1147"
  "Echo buffer status in minibuffer window."
  '((emacs          "29.1")
    (hide-mode-line "1.0.3"))
  :url "https://github.com/eki3z/mini-echo.el"
  :commit "3a490395652ff7938129f84c7154996672244baf"
  :revdesc "3a490395652f"
  :keywords '("frames")
  :authors '(("Eki Zhang" . "liuyinz95@gmail.com"))
  :maintainers '(("Eki Zhang" . "liuyinz95@gmail.com")))
